Module: Initium
- Defined in:
- lib/initium.rb,
lib/initium/command.rb,
lib/initium/version.rb
Overview
This is a placeholder documentation for the module.
Constant Summary collapse
- VERSION =
The semantic version number of the software.
"0.0.1"
Class Method Summary collapse
-
.command(p) ⇒ String
An example for a simple method called by a CLI command.
Class Method Details
.command(p) ⇒ String
An example for a simple method called by a CLI command.
8 9 10 |
# File 'lib/initium/command.rb', line 8 def self.command(p) "A dummy command called with parameter '#{p}'." end |